===============================
Python API Client for Ejabberd
===============================

| |docs| |circleci| |coveralls| |landscape| |scrutinizer|
| |version| |downloads| |wheel| |supported-versions| |supported-implementations|

.. |docs| image:: https://readthedocs.org/projects/pyejabberd/badge/?style=flat
    :target: https://pyejabberd.readthedocs.org/en/latest/
    :alt: Documentation Status

.. |circleci| image:: https://img.shields.io/circleci/project/dirkmoors/pyejabberd/master.svg?style=flat
    :alt: CircleCI Build Status
    :target: https://circleci.com/gh/dirkmoors/pyejabberd

.. |coveralls| image:: http://img.shields.io/coveralls/dirkmoors/pyejabberd/master.png?style=flat
    :alt: Coverage Status
    :target: https://coveralls.io/r/dirkmoors/pyejabberd

.. |landscape| image:: https://landscape.io/github/dirkmoors/pyejabberd/master/landscape.svg?style=flat
    :target: https://landscape.io/github/dirkmoors/pyejabberd
    :alt: Code Quality Status

.. |version| image:: http://img.shields.io/pypi/v/pyejabberd.png?style=flat
    :alt: PyPI Package latest release
    :target: https://pypi.python.org/pypi/pyejabberd

.. |downloads| image:: http://img.shields.io/pypi/dm/pyejabberd.png?style=flat
    :alt: PyPI Package monthly downloads
    :target: https://pypi.python.org/pypi/pyejabberd

.. |wheel| image:: https://pypip.in/wheel/pyejabberd/badge.png?style=flat
    :alt: PyPI Wheel
    :target: https://pypi.python.org/pypi/pyejabberd

.. |supported-versions| image:: https://pypip.in/py_versions/pyejabberd/badge.png?style=flat
    :alt: Supported versions
    :target: https://pypi.python.org/pypi/pyejabberd

.. |supported-implementations| image:: https://pypip.in/implementation/pyejabberd/badge.png?style=flat
    :alt: Supported imlementations
    :target: https://pypi.python.org/pypi/pyejabberd

.. |scrutinizer| image:: https://img.shields.io/scrutinizer/g/dirkmoors/pyejabberd/master.png?style=flat
    :alt: Scrtinizer Status
    :target: https://scrutinizer-ci.com/g/dirkmoors/pyejabberd/

* Free software: MIT license

Installation
============

::

    pip install pyejabberd

Documentation
=============

    https://pyejabberd.readthedocs.org/

Development
===========

To run the all tests run::

    tox
